@@ -69,7 +69,7 @@ class HttpMethodsMixin(HttpMethodsProtocol):
         return {}
 
     def __handle(self, verb, url, *args, **kwargs):
-        enforce_https(url)
+        enforce_https_except_localhost(url)
         kwargs.update(self.default_kwargs())
         return getattr(self.session, verb)(url, *args, **kwargs)
 
@@ -185,6 +185,7 @@ class RetrySession(HttpMethodsMixin):  # pylint: disable=too-few-public-methods
             backoff_factor=backoff_factor,
             method_whitelist=self._get_method_whitelist(),
             status_forcelist=status_forcelist,
+            raise_on_status=False,
         )
         adapter = HTTPAdapter(max_retries=retry)
         session.mount("http://", adapter)
@@ -331,7 +332,7 @@ class TimeoutPostRetrySession(TimeoutRetrySession):
         return PostRetrySession(num_retries)
 
 
-def enforce_https(url: str):
+def enforce_https_except_localhost(url: str):
     """
     Raises HTTPSRequired exception if required.
 
@@ -339,5 +340,5 @@ def enforce_https(url: str):
     :return: None
     :raises HTTPSRequired: if given url does not start with https
     """
-    if not url.startswith("https"):
+    if not url.startswith("https") and not url.startswith("http://localhost"):
         raise HTTPSRequired
